[SCM] WebKit Debian packaging branch, webkit-1.1, updated. upstream/1.1.19-706-ge5415e9

mrowe at apple.com mrowe at apple.com
Thu Feb 4 21:33:58 UTC 2010


The following commit has been merged in the webkit-1.1 branch:
commit 0c199bfd7de0b5c48ae80d389b47179125ab7ffd
Author: mrowe at apple.com <mrowe at apple.com@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Sun Jan 31 23:59:19 2010 +0000

    Roll r54095 out again without making a mess of the ChangeLog.
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@54116 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebCore/ChangeLog-2010-01-29 b/WebCore/ChangeLog-2010-01-29
index 265eefb..cce1125 100644
--- a/WebCore/ChangeLog-2010-01-29
+++ b/WebCore/ChangeLog-2010-01-29
@@ -21,28 +21,6 @@
         (WebCore::Geolocation::startRequest): Don't start timer if we're blocked on user consent.
         (WebCore::Geolocation::setIsAllowed): Start timer after user gives consent.
 
-2010-01-29  Chris Marrin  <cmarrin at apple.com>
-
-        Reviewed by Simon Fraser.
-
-        Fixed changed virtual function in GraphicsLayerCACF and call order issues
-        https://bugs.webkit.org/show_bug.cgi?id=34348
-        
-        The correct virtual function in GraphicsLayerCACF is now being
-        called. We also fixed an issue in QTMovieWin where the size
-        of the movie was not being set correctly because the call order
-        was changed.
-
-        * platform/graphics/win/GraphicsLayerCACF.cpp:
-        (WebCore::GraphicsLayerCACF::setContentsToMedia):
-        (WebCore::GraphicsLayerCACF::updateContentsMedia):
-        * platform/graphics/win/GraphicsLayerCACF.h:
-        (WebCore::GraphicsLayerCACF::):
-        * platform/graphics/win/QTMovieWin.cpp:
-        (QTMovieWinPrivate::task):
-        (QTMovieWinPrivate::setSize):
-        (QTMovieWinPrivate::updateMovieSize):
-
 2010-01-29  Jakob Petsovits  <jpetsovits at rim.com>
 
         Reviewed by Nikolas Zimmermann.
diff --git a/WebCore/platform/graphics/win/GraphicsLayerCACF.h b/WebCore/platform/graphics/win/GraphicsLayerCACF.h
index 0a52764..93ddf25 100644
--- a/WebCore/platform/graphics/win/GraphicsLayerCACF.h
+++ b/WebCore/platform/graphics/win/GraphicsLayerCACF.h
@@ -82,7 +82,7 @@ public:
     virtual void setContentsRect(const IntRect&);
 
     virtual void setContentsToImage(Image*);
-    virtual void setContentsToMedia(PlatformLayer*);
+    virtual void setContentsToVideo(PlatformLayer*);
     
     virtual PlatformLayer* platformLayer() const;
 
@@ -115,7 +115,7 @@ private:
     void updateLayerBackgroundColor();
 
     void updateContentsImage();
-    void updateContentsMedia();
+    void updateContentsVideo();
     void updateContentsRect();
     void updateGeometryOrientation();
     
@@ -129,7 +129,7 @@ private:
     enum ContentsLayerPurpose {
         NoContentsLayer = 0,
         ContentsLayerForImage,
-        ContentsLayerForMedia
+        ContentsLayerForVideo
     };
     
     ContentsLayerPurpose m_contentsLayerPurpose;
diff --git a/WebCore/platform/graphics/win/QTMovieWin.cpp b/WebCore/platform/graphics/win/QTMovieWin.cpp
index 8714517..8fd6c71 100644
--- a/WebCore/platform/graphics/win/QTMovieWin.cpp
+++ b/WebCore/platform/graphics/win/QTMovieWin.cpp
@@ -99,7 +99,6 @@ public:
     void deleteGWorld();
     void clearGWorld();
     void cacheMovieScale();
-    void updateMovieSize();
 
     void setSize(int, int);
 
@@ -260,16 +259,14 @@ void QTMovieWinPrivate::task()
             // we only need to erase the movie gworld when the load state changes to loaded while it
             //  is visible as the gworld is destroyed/created when visibility changes
             bool shouldRestorePlaybackState = false;
-            bool movieNewlyPlayable = loadState >= QTMovieLoadStateLoaded && m_loadState < QTMovieLoadStateLoaded;
-            m_loadState = loadState;
-            if (movieNewlyPlayable) {
-                updateMovieSize();
+            if (loadState >= QTMovieLoadStateLoaded && m_loadState < QTMovieLoadStateLoaded) {
                 if (m_visible)
                     clearGWorld();
                 cacheMovieScale();
                 shouldRestorePlaybackState = true;
             }
 
+            m_loadState = loadState;
             if (!m_movieController && m_loadState >= QTMovieLoadStateLoaded)
                 createMovieController();
             m_client->movieLoadStateChanged(m_movieWin);
@@ -406,6 +403,7 @@ void QTMovieWinPrivate::clearGWorld()
     MacSetPort(savePort);
 }
 
+
 void QTMovieWinPrivate::setSize(int width, int height)
 {
     if (m_width == width && m_height == height)
@@ -423,26 +421,17 @@ void QTMovieWinPrivate::setSize(int width, int height)
     ASSERT(m_scaleCached);
 #endif
 
-    updateMovieSize();
-}
-
-void QTMovieWinPrivate::updateMovieSize()
-{
-    if (!m_movie || m_loadState < QTMovieLoadStateLoaded)
-        return;
-
     Rect bounds; 
     bounds.top = 0;
     bounds.left = 0; 
-    bounds.right = m_width;
-    bounds.bottom = m_height;
+    bounds.right = width;
+    bounds.bottom = height;
     if (m_movieController)
         MCSetControllerBoundsRect(m_movieController, &bounds);
     SetMovieBox(m_movie, &bounds);
     updateGWorld();
 }
 
-
 void QTMovieWinPrivate::deleteGWorld()
 {
     ASSERT(m_gWorld);

diff --git a/WebCore/platform/graphics/win/GraphicsLayerCACF.cpp b/WebCore/platform/graphics/win/GraphicsLayerCACF.cpp
index ca7e496..5ec90b8 100644
--- a/WebCore/platform/graphics/win/GraphicsLayerCACF.cpp
+++ b/WebCore/platform/graphics/win/GraphicsLayerCACF.cpp
@@ -364,18 +364,21 @@ void GraphicsLayerCACF::setContentsToImage(Image* image)
         updateSublayerList();
 }
 
-void GraphicsLayerCACF::setContentsToMedia(PlatformLayer* mediaLayer)
+void GraphicsLayerCACF::setContentsToVideo(PlatformLayer* videoLayer)
 {
-    if (mediaLayer == m_contentsLayer)
-        return;
+    bool childrenChanged = false;
 
-    m_contentsLayer = mediaLayer;
-    m_contentsLayerPurpose = mediaLayer ? ContentsLayerForMedia : NoContentsLayer;
+    if (videoLayer != m_contentsLayer.get())
+        childrenChanged = true;
 
-    updateContentsMedia();
+    m_contentsLayer = videoLayer;
+    m_contentsLayerPurpose = videoLayer ? ContentsLayerForVideo : NoContentsLayer;
 
-    // This has to happen after updateContentsMedia
-    updateSublayerList();
+    updateContentsVideo();
+
+    // This has to happen after updateContentsVideo
+    if (childrenChanged)
+        updateSublayerList();
 }
 
 void GraphicsLayerCACF::setGeometryOrientation(CompositingCoordinatesOrientation orientation)
@@ -630,9 +633,9 @@ void GraphicsLayerCACF::updateContentsImage()
     }
 }
 
-void GraphicsLayerCACF::updateContentsMedia()
+void GraphicsLayerCACF::updateContentsVideo()
 {
     // Media layer was set as m_contentsLayer, and will get parented in updateSublayerList().
     if (m_contentsLayer) {
         setupContentsLayer(m_contentsLayer.get());
         updateContentsRect();
@@ -630,9 +633,9 @@ void GraphicsLayerCACF::updateContentsImage()
 {
-    // Media layer was set as m_contentsLayer, and will get parented in updateSublayerList().
+    // Video layer was set as m_contentsLayer, and will get parented in updateSublayerList().
     if (m_contentsLayer) {
         setupContentsLayer(m_contentsLayer.get());
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list